@@ -15,12 +15,13 @@
 #  limitations under the License.
 
 
+ 
 import sys
 import os
 import stat
 import re
 from os import path
-from calculate.core.server.core_interfaces import MethodsInterface
+from .server.core_interfaces import MethodsInterface
 from calculate.lib.utils.files import (makeDirectory, removeDir, tar_directory,
                                        FilePermission, find, listDirectory,
                                        FilesError, process, readFileEx,
@@ -32,7 +33,7 @@ from calculate.lib.cl_template import Template
 from calculate.lib.utils.accounts import Passwd, Group, Shadow
 
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
-from variables.action import Actions
+from .variables.action import Actions
 import tarfile
 import shutil
 import glob
@@ -120,7 +121,7 @@ class Backup(MethodsInterface):
                 # исключить из переноса файлы, которые принадлежат пакетам,
                 # которые не установлены в системе
                 contents = f.extractfile(f.getmember(contents_name))
-                pkg_file = [x.split()[:3:2] for x in contents]
+                pkg_file = [x.decode("UTF-8").split()[:3:2] for x in contents]
                 not_installed_files = [
                     x for x in pkg_file
                     if not any(getInstalledAtom(x[0].partition(":")[0]))]
@@ -161,7 +162,7 @@ class Backup(MethodsInterface):
                                 data_system = readFile(fn_system)
                                 extr_file = f.extractfile(ti)
                                 if extr_file:
-                                    data_ti = extr_file.read()
+                                    data_ti = extr_file.read().decode("UTF-8")
                                     if self.is_equal_files(data_system,
                                                            data_ti):
                                         continue
@@ -283,7 +284,7 @@ class Backup(MethodsInterface):
         try:
             for fn in find(source_etc_dn, filetype=FindFileType.RegularFile):
                 if (not reCfg.search(fn) and
-                            " Modified Calculate" in readFileEx(fn,
+                            b" Modified Calculate" in readFileEx(fn,
                                                                 headbyte=300)):
                     self.backup_file(fn, root_dn, prefix=source_dn)
         except (OSError, IOError) as e:
@@ -595,10 +596,8 @@ class Backup(MethodsInterface):
                          if (x.endswith('site-packages') and
                              x.startswith('/usr/lib'))]
         ret_list = []
-        for module, modDir in chain(
-                *map(lambda x: map(lambda y: (path.basename(y), y),
-                                   listDirectory(x, True, True)),
-                     site_packages)):
+        for module, modDir in chain(*(((path.basename(y), y) for y 
+                in listDirectory(x, True, True)) for x in site_packages)):
             if path.exists(path.join(modDir, "backup_%s.py" % module)):
                 if not "calculate-%s" % module in ret_list:
                     ret_list.append("calculate-%s" % module)
