@@ -57,14 +57,18 @@ class VariableClCorePkgName(Variable):
     def choice(self):
         if self.Get('cl_ebuild_phase'):
             return [""]
-        return [""] + ["all"] + sorted(
-            set(chain(*map(lambda x: map(
-                lambda y: (y[0].rpartition('-')[0]
-                           if y[2].startswith('r') else y[0]),
-                imap(lambda y: y.rpartition('-'),
-                     listDirectory(x))),
-                           listDirectory('/var/db/pkg', onlyDir=True,
-                                         fullPath=True)))))
+        # return [""] + ["all"] + sorted(
+        #     set(chain(*map(lambda x: map(
+        #         lambda y: (y[0].rpartition('-')[0]
+        #                    if y[2].startswith('r') else y[0]),
+        #         map(lambda y: y.rpartition('-'),
+        #              listDirectory(x))),
+        #                    listDirectory('/var/db/pkg', onlyDir=True,
+        #                                  fullPath=True)))))
+        return [""] + ["all"] + sorted(set(chain(*(((y[0].rpartition('-')[0] 
+            if y[2].startswith('r') else y[0]) for y 
+                in (z.rpartition('-') for z in listDirectory(x))) for x 
+            in listDirectory('/var/db/pkg', onlyDir=True,fullPath=True)))))
 
 
 class VariableClCorePkgVersionOpt(Variable):
@@ -267,8 +271,8 @@ class VariableClCorePkgCategory(Variable):
         if pkgname not in self.pkgCategories:
             self.pkgCategories[pkgname] = \
                 glob.glob('/usr/portage/*/%s' % pkgname)
-        return map(lambda x: path.split(path.split(x)[0])[1],
-                   self.pkgCategories[pkgname])
+        return [path.split(path.split(x)[0])[1] for x 
+            in self.pkgCategories[pkgname]]
 
     def get(self):
         category = isPkgInstalled(self.Get('cl_core_pkg_name'))
